pub struct YoloModelSession {
pub session: Session,
pub labels: Vec<ArcStr>,
pub probability_threshold: Option<f32>,
pub iou_threshold: Option<f32>,
}Expand description
The YOLO model.
It is a wrapper around the ONNX runtime session and the YOLO labels.
Fields
session: Sessionlabels: Vec<ArcStr>probability_threshold: Option<f32>iou_threshold: Option<f32>Implementations
Sourceimpl YoloModelSession
impl YoloModelSession
Sourcepub fn new(
session: Session,
labels: impl Iterator<Item = impl Into<ArcStr>>,
) -> Self
pub fn new( session: Session, labels: impl Iterator<Item = impl Into<ArcStr>>, ) -> Self
Wrap a ONNX session to a YoloModelSession.
The session is the ONNX runtime session, and the labels are the YOLO labels.
Sourcepub fn new_v8(session: Session) -> Self
pub fn new_v8(session: Session) -> Self
Wrap a ONNX session to a YoloModelSession based on the labels of YOLO v8 (v11).
Sourcepub fn from_filename_v8(filename: impl AsRef<Path>) -> Result<Self, YoloError>
pub fn from_filename_v8(filename: impl AsRef<Path>) -> Result<Self, YoloError>
Load the YOLO ONNX model from a filename.
You can use this function to load a YOLO v8 (v11) model from a file.
The filename is the path to the ONNX model file.
You can export the ONNX model file according to Ultralytics’ manual.
pub fn get_labels(&self) -> &[ArcStr]
pub fn get_probability_threshold(&self) -> f32
pub fn get_iou_threshold(&self) -> f32